Index: code/branches/libraries/cmake/BuildConfig.cmake
===================================================================
--- code/branches/libraries/cmake/BuildConfig.cmake	(revision 5649)
+++ code/branches/libraries/cmake/BuildConfig.cmake	(revision 5666)
@@ -31,5 +31,5 @@
 SET(DEFAULT_LIBRARY_PATH lib)
 SET(DEFAULT_ARCHIVE_PATH lib/static)
-SET(DEFAULT_PLUGIN_PATH  lib/plugins)
+SET(DEFAULT_MODULE_PATH  lib/modules)
 SET(DEFAULT_DOC_PATH     doc)
 SET(DEFAULT_MEDIA_PATH   media)
@@ -41,5 +41,5 @@
 SET(CMAKE_LIBRARY_OUTPUT_DIRECTORY ${CMAKE_BINARY_DIR}/${DEFAULT_LIBRARY_PATH})
 SET(CMAKE_ARCHIVE_OUTPUT_DIRECTORY ${CMAKE_BINARY_DIR}/${DEFAULT_ARCHIVE_PATH})
-SET(CMAKE_PLUGIN_OUTPUT_DIRECTORY  ${CMAKE_BINARY_DIR}/${DEFAULT_PLUGIN_PATH})
+SET(CMAKE_MODULE_OUTPUT_DIRECTORY  ${CMAKE_BINARY_DIR}/${DEFAULT_MODULE_PATH})
 # Do not set doc and media, rather check in the two subdirectories
 # whether they concur with the DEFAULT_..._PATH
@@ -72,4 +72,6 @@
 ENDIF()
 
+# Set the extension of the dynamic modules
+SET(ORXONOX_MODULE_EXTENSION ".module")
 
 ################# OGRE Plugins ##################
@@ -134,5 +136,5 @@
   SET(ORXONOX_LIBRARY_INSTALL_PATH ${DEFAULT_LIBRARY_PATH})
   SET(ORXONOX_ARCHIVE_INSTALL_PATH ${DEFAULT_ARCHIVE_PATH})
-  SET(ORXONOX_PLUGIN_INSTALL_PATH  ${DEFAULT_PLUGIN_PATH})
+  SET(ORXONOX_MODULE_INSTALL_PATH  ${DEFAULT_MODULE_PATH})
   SET(ORXONOX_DOC_INSTALL_PATH     ${DEFAULT_DOC_PATH})
   SET(ORXONOX_MEDIA_INSTALL_PATH   ${DEFAULT_MEDIA_PATH})
@@ -145,5 +147,5 @@
   SET(ORXONOX_LIBRARY_INSTALL_PATH ${CMAKE_INSTALL_PREFIX}/lib/orxonox)
   SET(ORXONOX_ARCHIVE_INSTALL_PATH ${CMAKE_INSTALL_PREFIX}/lib/orxonox/static)
-  SET(ORXONOX_PLUGIN_INSTALL_PATH  ${CMAKE_INSTALL_PREFIX}/lib/orxonox/plugins)
+  SET(ORXONOX_MODULE_INSTALL_PATH  ${CMAKE_INSTALL_PREFIX}/lib/orxonox/modules)
   SET(ORXONOX_DOC_INSTALL_PATH     ${CMAKE_INSTALL_PREFIX}/share/doc/orxonox)
   SET(ORXONOX_MEDIA_INSTALL_PATH   ${CMAKE_INSTALL_PREFIX}/share/orxonox)
@@ -156,5 +158,5 @@
   SET(ORXONOX_LIBRARY_INSTALL_PATH ${CMAKE_INSTALL_PREFIX}/${DEFAULT_LIBRARY_PATH})
   SET(ORXONOX_ARCHIVE_INSTALL_PATH ${CMAKE_INSTALL_PREFIX}/${DEFAULT_ARCHIVE_PATH})
-  SET(ORXONOX_PLUGIN_INSTALL_PATH  ${CMAKE_INSTALL_PREFIX}/${DEFAULT_PLUGIN_PATH})
+  SET(ORXONOX_MODULE_INSTALL_PATH  ${CMAKE_INSTALL_PREFIX}/${DEFAULT_MODULE_PATH})
   SET(ORXONOX_DOC_INSTALL_PATH     ${CMAKE_INSTALL_PREFIX}/${DEFAULT_DOC_PATH})
   SET(ORXONOX_MEDIA_INSTALL_PATH   ${CMAKE_INSTALL_PREFIX}/${DEFAULT_MEDIA_PATH})
Index: code/branches/libraries/cmake/TargetUtilities.cmake
===================================================================
--- code/branches/libraries/cmake/TargetUtilities.cmake	(revision 5649)
+++ code/branches/libraries/cmake/TargetUtilities.cmake	(revision 5666)
@@ -35,5 +35,5 @@
  #      NO_SOURCE_GROUPS:  Don't create msvc source groups
  #      STATIC/SHARED:     Inherited from ADD_LIBRARY
  #      PLUGIN:            For dynamic plugin libraries
  #      WIN32:             Inherited from ADD_EXECUTABLE
  #      PCH_NO_DEFAULT:    Do not make precompiled header files default if
@@ -81,5 +81,5 @@
   SET(_switches   FIND_HEADER_FILES  EXCLUDE_FROM_ALL  ORXONOX_EXTERNAL
                   NO_DLL_INTERFACE   NO_SOURCE_GROUPS  ${_additional_switches}
-                  PCH_NO_DEFAULT     NO_INSTALL        PLUGIN)
+                  PCH_NO_DEFAULT     NO_INSTALL        MODULE)
   SET(_list_names LINK_LIBRARIES  VERSION   SOURCE_FILES  DEFINE_SYMBOL
                   TOLUA_FILES     PCH_FILE  PCH_EXCLUDE OUTPUT_NAME)
@@ -148,6 +148,7 @@
   ENDIF()
 
-  # PLUGIN A, always create shared libraries
-  IF(_arg_PLUGIN)
+  # MODULE A
+  # Always create shared libraries
+  IF(_arg_MODULE)
     SET(_arg_SHARED SHARED)
     SET(_arg_STATIC)
@@ -163,11 +164,11 @@
   ENDIF()
 
-  # PLUGIN B
-  IF (_arg_PLUGIN)
+  # MODULE B
+  IF (_arg_MODULE)
     SET_TARGET_PROPERTIES(${_target_name} PROPERTIES
-      RUNTIME_OUTPUT_DIRECTORY ${CMAKE_PLUGIN_OUTPUT_DIRECTORY} # Windows
-      LIBRARY_OUTPUT_DIRECTORY ${CMAKE_PLUGIN_OUTPUT_DIRECTORY} # Unix
+      RUNTIME_OUTPUT_DIRECTORY ${CMAKE_MODULE_OUTPUT_DIRECTORY} # Windows
+      LIBRARY_OUTPUT_DIRECTORY ${CMAKE_MODULE_OUTPUT_DIRECTORY} # Unix
     )
-    ADD_PLUGIN(${_target_name})
+    ADD_MODULE(${_target_name})
   ENDIF()
 
@@ -200,8 +201,8 @@
 
   IF(NOT _arg_STATIC AND NOT _arg_NO_INSTALL)
-    IF(_arg_PLUGIN)
+    IF(_arg_MODULE)
       INSTALL(TARGETS ${_target_name}
-        RUNTIME DESTINATION ${ORXONOX_PLUGIN_INSTALL_PATH}
-        LIBRARY DESTINATION ${ORXONOX_PLUGIN_INSTALL_PATH}
+        RUNTIME DESTINATION ${ORXONOX_MODULE_INSTALL_PATH}
+        LIBRARY DESTINATION ${ORXONOX_MODULE_INSTALL_PATH}
       )
     ELSE()
@@ -216,8 +217,8 @@
 
 
-# Creates a helper file with name <name_of_the_library>.plugin
-# This helps finding dynamically loadable plugins at runtime
-
-FUNCTION(ADD_PLUGIN _target)
+# Creates a helper file with name <name_of_the_library>.module
+# This helps finding dynamically loadable modules at runtime
+
+FUNCTION(ADD_MODULE _target)
   # We use the properties to get the name because the librarys name may differ from
   # the target name (for example orxonox <-> liborxonox)
@@ -228,23 +229,23 @@
   IF(CMAKE_CONFIGURATION_TYPES)
     FOREACH(_config ${CMAKE_CONFIGURATION_TYPES})
-      SET(_plugin_filename ${CMAKE_PLUGIN_OUTPUT_DIRECTORY}/${_config}/${_target_name}.plugin)
-
-      FILE(WRITE ${_plugin_filename})
+      SET(_module_filename ${CMAKE_MODULE_OUTPUT_DIRECTORY}/${_config}/${_target_name}${ORXONOX_MODULE_EXTENSION})
+
+      FILE(WRITE ${_module_filename})
 
       INSTALL(
-        FILES ${_plugin_filename}
-        DESTINATION ${ORXONOX_PLUGIN_INSTALL_PATH}
+        FILES ${_module_filename}
+        DESTINATION ${ORXONOX_MODULE_INSTALL_PATH}
         CONFIGURATIONS ${_config}
       )
     ENDFOREACH()
   ELSE()
-    SET(_plugin_filename ${CMAKE_PLUGIN_OUTPUT_DIRECTORY}/${_target_name}.plugin)
-
-    FILE(WRITE ${_plugin_filename})
+    SET(_module_filename ${CMAKE_MODULE_OUTPUT_DIRECTORY}/${_target_name}${ORXONOX_MODULE_EXTENSION})
+
+    FILE(WRITE ${_module_filename})
 
     INSTALL(
-      FILES ${_plugin_filename}
-      DESTINATION ${ORXONOX_PLUGIN_INSTALL_PATH}
+      FILES ${_module_filename}
+      DESTINATION ${ORXONOX_MODULE_INSTALL_PATH}
     )
   ENDIF()
-ENDFUNCTION(ADD_PLUGIN)
+ENDFUNCTION(ADD_MODULE)
@@ -35,5 +35,5 @@
  #      NO_SOURCE_GROUPS:  Don't create msvc source groups
  #      STATIC/SHARED:     Inherited from ADD_LIBRARY
- #      PLUGIN:            For dynamic plugin libraries
+ #      MODULE:            For dynamic module libraries
  #      WIN32:             Inherited from ADD_EXECUTABLE
  #      PCH_NO_DEFAULT:    Do not make precompiled header files default if
